Learn R Programming

xegaPermGene (version 1.0.0.1)

xegaPermMutateGeneBestGreedy: Mutate a gene (by inserting the best greedy path at a random start position with a random length of k).

Description

xegaPermMutateGeneBestGreedy mutates a permutation by inserting the best greedy path of length k at a random position start.

Usage

xegaPermMutateGeneBestGreedy(gene, lF)

Value

A Permutation

Arguments

gene

A Permutation.

lF

Local configuration of the genetic algorithm.

Details

The path length k is exponentially decaying with exponential decay constant lF$lambda().

See Also

Other Mutation: xegaPermMutateGene2Opt(), xegaPermMutateGeneGreedy(), xegaPermMutateGeneOrderBased(), xegaPermMutateGenekInversion(), xegaPermMutateGenekOptLK(), xegaPermMutateMix()

Examples

Run this code
gene1<-xegaPermInitGene(lFxegaPermGene)
xegaPermDecodeGene(gene1, lFxegaPermGene)
gene<-xegaPermMutateGeneGreedy(gene1, lFxegaPermGene)
xegaPermDecodeGene(gene, lFxegaPermGene)

Run the code above in your browser using DataLab