powered by
xegaPermMutateGeneGreedy mutates a permutation by inserting a greedy path of length k at a random position start.
xegaPermMutateGeneGreedy
k
start
xegaPermMutateGeneGreedy(gene, lF)
A Permutation.
Local configuration of the genetic algorithm.
The path length k is exponentially decaying with exponential decay constant lambda.
lambda
Other Mutation: xegaPermMutateGene2Opt(), xegaPermMutateGeneBestGreedy(), xegaPermMutateGeneOrderBased(), xegaPermMutateGenekInversion(), xegaPermMutateGenekOptLK(), xegaPermMutateMix()
xegaPermMutateGene2Opt()
xegaPermMutateGeneBestGreedy()
xegaPermMutateGeneOrderBased()
xegaPermMutateGenekInversion()
xegaPermMutateGenekOptLK()
xegaPermMutateMix()
gene1<-xegaPermInitGene(lFxegaPermGene) xegaPermDecodeGene(gene1, lFxegaPermGene) gene<-xegaPermMutateGeneGreedy(gene1, lFxegaPermGene) xegaPermDecodeGene(gene, lFxegaPermGene)
Run the code above in your browser using DataLab