Learn R Programming

xegaPermGene (version 1.0.0.1)

xegaPermMutationFactory: Configure the mutation function of a genetic algorithm.

Description

xegaPermMutationFactory implements the selection of one of the gene mutation functions in this package by specifying a text string. The selection fails ungracefully (produces a runtime error) if the label does not match. The functions are specified locally.

Current Support:

  1. "MutateGene" returns xegaPermMutateGeneOrderBased.

  2. "MutateGeneOrderBased" returns xegaPermMutateGeneOrderBased.

  3. "MutateGenekInversion" returns xegaPermMutateGenekInversion.

  4. "MutateGene2Opt" returns xegaPermMutateGene2Opt.

  5. "MutateGenekOptLK" returns xegaPermMutateGenekOptLK.

  6. "MutateGeneGreedy" returns xegaPermMutateGeneGreedy.

  7. "MutateGeneBestGreedy" returns xegaPermMutateGeneBestGreedy.

  8. "MutateGeneMix" returns xegaPermMutateMix.

Usage

xegaPermMutationFactory(method = "MutateGene")

Value

A permutation based mutation function.

Arguments

method

The name of the mutation method.

See Also

Other Configuration: lFxegaPermGene, xegaPermCrossoverFactory()

Examples

Run this code
xegaPermMutationFactory(method="MutateGene")

Run the code above in your browser using DataLab