powered by
xegaPermMutateGeneBestGreedy mutates a permutation by inserting the best greedy path of length k at a random position start.
xegaPermMutateGeneBestGreedy
k
start
xegaPermMutateGeneBestGreedy(gene, lF)
A Permutation
A Permutation.
Local configuration of the genetic algorithm.
The path length k is exponentially decaying with exponential decay constant lF$lambda().
lF$lambda()
Other Mutation: xegaPermMutateGene2Opt(), xegaPermMutateGeneGreedy(), xegaPermMutateGeneOrderBased(), xegaPermMutateGenekInversion(), xegaPermMutateGenekOptLK(), xegaPermMutateMix()
xegaPermMutateGene2Opt()
xegaPermMutateGeneGreedy()
xegaPermMutateGeneOrderBased()
xegaPermMutateGenekInversion()
xegaPermMutateGenekOptLK()
xegaPermMutateMix()
gene1<-xegaPermInitGene(lFxegaPermGene) xegaPermDecodeGene(gene1, lFxegaPermGene) gene<-xegaPermMutateGeneGreedy(gene1, lFxegaPermGene) xegaPermDecodeGene(gene, lFxegaPermGene)
Run the code above in your browser using DataLab